@@ -6,23 +6,26 @@ OC.L10N.register(
     "Rename" : "إعادة التسمية",
     "Move" : "نقل",
     "Delete" : "حذف ",
-    "Save" : "حفظ",
+    "New" : "جديد",
     "New folder" : "مجلد جديد",
     "Grid view" : "عرض شبكي",
     "List view" : "عرض على شكل قائمة",
-    "Create" : "إنشاء",
+    "Select all" : "تحديد الكل",
     "Cancel" : "إلغاء",
-    "Public" : "للعامة",
+    "Recent" : "الحديثة",
+    "Add a bookmark" : "إضافة فاصلة مرجعية",
     "Import" : "استيراد",
     "Export" : "تصدير",
     "Recently added" : "اضيفت مؤخرا",
     "Last modified" : "آخر تعديل",
     "Clear data" : "مسح البيانات",
-    "URL" : "الرابط",
+    "Title" : "العنوان",
+    "Link" : "الرابط",
     "Tags" : "الوسوم",
+    "Attachments" : "المرفقات",
     "Notes" : "الملاحظات",
-    "Sharing" : "المشاركة",
     "Owner" : "المالك",
+    "Sharing" : "المشاركة",
     "Share link" : "مشاركة الرابط",
     "Copy link" : "انسخ الرابط",
     "Allow editing" : "السماح بالتعديلات",
@@ -30,9 +33,7 @@ OC.L10N.register(
     "Select" : "تحديد",
     "Previews" : "المعاينات",
     "Privacy" : "الخصوصية",
-    "Add a bookmark" : "إضافة فاصلة مرجعية",
-    "Title" : "العنوان",
-    "Link" : "الرابط",
-    "Folder" : "مجلد"
+    "Folder" : "مجلد",
+    "Save" : "حفظ"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
