@@ -5,17 +5,21 @@ OC.L10N.register(
     "Rename" : "Adenvel",
     "Move" : "Diplasañ",
     "Delete" : "Dilemel",
-    "Save" : "Entilañ",
+    "New" : "Nevez",
     "New folder" : "Heuliad nevez",
     "Grid view" : "Diskwell ar roued",
     "List view" : "Gwelidik listenn",
-    "Create" : "Krouiñ",
+    "Select all" : "Dibab pep tra",
     "Cancel" : "Arrest",
-    "Public" : "Publik",
+    "Recent" : "Nevez",
+    "Broken links" : "Liammoù toret",
+    "Import" : "Emporzhiañ ",
     "Recently added" : "Ouzpennet n'eus ket pel zo",
+    "Enter the path of a folder where bookmarked files should be stored" : "Lakait hent an teuliad lec'h ma vo enrollet ar restroù gant ur merket pajenn",
     "Clear data" : "Lemel ar roadennoù",
-    "URL" : "URL",
+    "Link" : "Liamm",
     "Tags" : "Klavioù",
+    "Owner" : "Perc'henner",
     "Sharing" : "Rannan",
     "Share link" : "Rannan liamm",
     "Copy link" : "Kopiañ al liamm",
@@ -23,7 +27,7 @@ OC.L10N.register(
     "Link copied" : "Liamm eilet",
     "Select" : "Dibab",
     "Privacy" : "Prevezder",
-    "Link" : "Liamm",
-    "Folder" : "Teuliad"
+    "Folder" : "Teuliad",
+    "Save" : "Enrollañ"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
