@@ -5,25 +5,25 @@ OC.L10N.register(
     "Rename" : "Ailenwi",
     "Move" : "Symud",
     "Delete" : "Dileu",
-    "Save" : "Cadw",
+    "New" : "Newydd",
     "New folder" : "Ffolder newydd",
     "Grid view" : "Golwg grid",
     "List view" : "Golwg rhestr",
-    "Create" : "Creu",
     "Cancel" : "Diddymu",
+    "Recent" : "Diweddar",
     "Import" : "Mewnforio",
     "Export" : "Allforio",
     "Recently added" : "Ychwanegwyd yn ddiweddar",
     "Last modified" : "Newidiwyd diwethaf",
-    "URL" : "URL",
+    "Title" : "Teitl",
+    "Link" : "Dolen",
     "Tags" : "Tagiau",
     "Notes" : "Nodiadau",
     "Owner" : "Owner",
     "Share link" : "Rhannu dolen",
     "Copy link" : "Copïo dolen",
     "Select" : "Select",
-    "Title" : "Teitl",
-    "Link" : "Dolen",
-    "Folder" : "Plygell"
+    "Folder" : "Plygell",
+    "Save" : "Cadw"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
