@@ -5,33 +5,34 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Move" : "Mover",
     "Delete" : "Eliminar",
-    "Save" : "Guardar",
+    "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
     "Grid view" : "Vista de cuadrícula",
     "List view" : "Vista de lista",
-    "Create" : "Crear",
+    "Select all" : "Seleccionar todo",
     "Cancel" : "Cancelar",
-    "Public" : "Público",
+    "Recent" : "Reciente",
     "Import" : "Importar",
     "Export" : "Exportar",
     "Recently added" : "Agregado recientemente",
     "Alphabetically" : "Alfabéticamente",
     "Last modified" : "Última modificación",
-    "Clear data" : "Borrar datos",
     "Bookmarklet" : "Marcador a código",
-    "URL" : "URL",
+    "Clear data" : "Borrar datos",
+    "Title" : "Título",
+    "Link" : "Link",
     "Tags" : "Etiquetas",
+    "Attachments" : "Adjuntos",
     "Notes" : "Notas",
-    "Sharing" : "Compartiendo",
     "Owner" : "Dueño",
+    "Sharing" : "Compartiendo",
     "Share link" : "Compartir enlace",
     "Copy link" : "Copiar enlace",
     "Allow editing" : "Permitir edición",
     "Link copied" : "Link copiado",
     "Select" : "Seleccionar",
     "Privacy" : "Privacidad",
-    "Title" : "Título",
-    "Link" : "Link",
-    "Folder" : "Carpeta"
+    "Folder" : "Carpeta",
+    "Save" : "Guardar"
 },
 "nplurals=2; plural=(n != 1);");
