@@ -2,19 +2,42 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "Kirjanmerkit",
+    "You bookmarked \"%s\"" : "Lisäsit kirjanmerkin \"%s\"",
+    "%1$s bookmarked \"%2$s\"" : "%1$s lisäsi kirjanmerkin \"%2$s\"",
+    "Someone bookmarked \"%s\"" : "Joku lisäsi kirjanmerkin \"%s\"",
+    "You deleted \"%s\"" : "Poistit \"%s\"",
+    "%1$s deleted \"%2$s\"" : "%1$s poisti \"%2$s\"",
+    "Someone deleted \"%s\"" : "Joku poisti \"%s\"",
+    "You created folder \"%s\"" : "Loit kansion \"%s\"",
+    "%1$s created folder \"%2$s\"" : "%1$s loi kansion \"%2$s\"",
+    "Someone created folder \"%s\"" : "Joku loi kansion \"%s\"",
+    "You moved folder \"%s\"" : "Siirsit kansion \"%s\"",
+    "%1$s moved folder \"%2$s\"" : "%1$s siirsi kansion \"%2$s\"",
+    "Someone moved folder \"%s\"" : "Joku siirsi kansion \"%s\"",
+    "You deleted folder \"%s\"" : "Poistit kansion \"%s\"",
+    "%1$s deleted folder \"%2$s\"" : "%1$s poisti kansion \"%2$s\"",
+    "Someone deleted folder \"%s\"" : "Joku poisti kansion \"%s\"",
+    "You shared folder \"%1$s\" with %2$s" : "Jaoit kansion \"%1$s\" henkilön %2$s kanssa",
+    "You shared folder \"%s\" with someone" : "Jaoit kansion \"%s\" jonkun kanssa",
+    "%1$s shared folder \"%2$s\" with you" : "%1$s jakoi kansion \"%2$s\" kanssasi",
+    "Someone shared folder \"%s\" with you" : "Joku jakoi kansion \"%s\" kanssasi",
     "No file provided for import" : "Tuotavaa tiedostoa ei ole valittu",
     "Unsupported file type for import" : "Tiedoston tyyppi ei ole tuotavaa muotoa",
     "Bookmarks shared by %s" : "Henkilön %s jakamat kirjanmerkit",
+    "Bookmark" : "Kirjanmerkki",
+    "Bookmark deleted" : "Kirjanmerkki poistettu",
+    "Bookmark created" : "Kirjanmerkki luotu",
+    "Bookmark moved" : "Kirjanmerkki siirretty",
+    "Bookmark updated" : "Kirjanmerkki päivitetty",
+    "Create bookmark" : "Luo kirjanmerkki",
     "A Bookmark manager for Nextcloud" : "Kirjanmerkkien hallinta Nextcloudille",
     "Select bookmark" : "Valitse kirjanmerkki",
     "Details" : "Tiedot",
     "Rename" : "Nimeä uudelleen",
     "Move" : "Siirrä",
     "Delete" : "Poista",
-    "Enter bookmark title" : "Anna nimi kirjanmerkille",
-    "Save" : "Tallenna",
-    "No bookmarks here" : "Ei kirjanmerkkejä täällä",
     "Select one or more tags" : "Valitse yksi tai useampi tunniste",
+    "New" : "Uusi",
     "New bookmark" : "Uusi kirjanmerkki",
     "New folder" : "Uusi kansio",
     "Grid view" : "Ruudukkonäkymä",
@@ -22,27 +45,31 @@ OC.L10N.register(
     "Move selection" : "Siirrä valintaa",
     "Delete selection" : "Poista valinta",
     "Open all selected" : "Avaa kaikki valitut",
-    "Select all visible" : "Valitse kaikki näkyvät",
+    "Select all" : "Valitse kaikki",
     "Cancel selection" : "Peruuta valinta",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Valittu {folders} kansiota ja {bookmarks} kirjanmerkkiä",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valittu %n kirjanmerkki","Valittu %n kirjanmerkkiä"],
     "_Selected %n folder_::_Selected %n folders_" : ["Valittu %n kansio","Valittu %n kansiota"],
     "Enter a link" : "Anna linkki",
-    "Create" : "Luo",
-    "Cancel" : "Peruuta",
-    "Enter folder title" : "Anna nimi kansiolle",
     "Select folder" : "Valitse kansio",
+    "Enter folder title" : "Anna nimi kansiolle",
     "Shared by {user}" : "Jakanut {user}",
-    "Shared privately" : "Jaettu yksityisesti",
-    "Public" : "Julkinen",
     "Root folder" : "Juurikansio",
+    "Cancel" : "Peruuta",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Siirretään %n kansio ja joitain kirjanmerkkejä","Siirretään %n kansiota ja joitain kirjanmerkkejä"],
     "_Moving %n folder_::_Moving %n folders_" : ["Siirretään %n kansio","Siirretään %n kansiota"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Siirretään %n kirjanmerkki","Siirretään %n kirjanmerkkiä"],
-    "New Bookmark" : "Uusi kirjanmerkki",
-    "All Bookmarks" : "Kaikki kirjanmerkit",
-    "Recent Bookmarks" : "Uusimmat kirjanmerkit",
+    "All bookmarks" : "Kaikki kirjanmerkit",
+    "Recent" : "Viimeisimmät",
+    "Archived" : "Arkistoitu",
+    "Broken links" : "Rikkinäisiä linkkejä",
+    "Filter tags" : "Suodata tunnisteita",
+    "Untagged" : "Ilman tunnistetta",
     "{used} bookmarks of {available} available" : "{used}/{available} kirjanmerkkiä käytettävissä",
+    "No archived bookmarks" : "Ei arkistoituja kirjanmerkkejä",
+    "No bookmarks here" : "Ei kirjanmerkkejä täällä",
+    "Add a bookmark" : "Lisää kirjanmerkki",
+    "Import bookmarks" : "Tuo kirjanmerkit",
     "Import" : "Tuo",
     "Export" : "Vie",
     "Sorting" : "Lajittelu",
@@ -50,20 +77,25 @@ OC.L10N.register(
     "Alphabetically" : "Aakkosjärjestys",
     "Most visited" : "Vierailuimmat",
     "Last modified" : "Viimeksi muokattu",
-    "RSS Feed" : "RSS-syöte",
-    "Clear data" : "Tyhjennä tiedot",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "Poista kaikki tililläsi olevat kirjanmerkit pysyvästi. Tätä toimintoa ei voi perua!",
-    "Delete all bookmarks" : "Poista kaikki kirjanmerkit",
+    "Custom order" : "Mukautettu järjestys",
     "Bookmarklet" : "Sovelluskirjanmerkki",
+    "Clear data" : "Tyhjennä tiedot",
+    "Permanently remove all bookmarks from your account." : "Poista kaikki tililläsi olevat kirjanmerkit pysyvästi.",
+    "Delete all bookmarks" : "Poista kaikki kirjanmerkit",
     "Do you really want to delete all your bookmarks?" : "Haluatko varmasti poistaa kaikki kirjanmerkkisi?",
-    "URL" : "URL-osoite",
+    "Title" : "Otsikko",
+    "Link" : "Linkki",
     "Creation date" : "Luontipäivä",
     "Tags" : "Tunnisteet",
-    "Select tags are create new ones" : "Valitse tunnisteet tai luo uusia",
+    "Select tags and create new ones" : "Valitse tunnisteet tai luo uusia",
+    "Attachments" : "Liitteet",
+    "Archived version" : "Arkistoitu versio",
+    "Open archived file" : "Avaa arkistoitu tiedosto",
     "Notes" : "Muistiinpanot",
-    "Sharing" : "Jakaminen",
+    "Notes for this bookmark …" : "Muistiinpanot tähän kirjanmerkkiin liittyen…",
     "{time} ago" : "{time} sitten",
     "Owner" : "Omistaja",
+    "Sharing" : "Jakaminen",
     "Select a user or group" : "Valitse käyttäjä tai ryhmä",
     "Share link" : "Jaa linkki",
     "Copy link" : "Kopioi linkki",
@@ -77,25 +109,27 @@ OC.L10N.register(
     "RSS feed copied" : "RSS-syöte kopioitu",
     "Select" : "Valitse",
     "Previews" : "Esikatselut",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Näyttääkseen aitoja kuvakaappauksia kirjanmerkkeihin lisäämistäsi verkkosivuista, Kirjanmerkit voi käyttää kolmannen osapuolen palvelua niiden luomiseen.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Voit rekisteröityä veloituksetta osoitteessa screeenly.com tai pystyttää oman palvelimen.",
     "Screeenly API URL" : "Screeenly-palvelun API:n URL",
     "Screeenly API key" : "Screeenly-palvelun API-avain",
+    "Webshot" : "Webshot",
+    "Webshot API URL" : "Webshotin API:n URL",
+    "ScreenshotMachine" : "ScreenshotMachine",
+    "ScreenshotMachine API key" : "ScreenshotMachinen API-avain",
     "Privacy" : "Yksityisyys",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Kirjanmerkkisovellus pyrkii niille sivuille, jotka lisäät kirjanmerkkeihin, jotta sivuista voidaan noutaa automaattisesti lisätietoja.",
     "Performance" : "Suorituskyky",
-    "In an installation with  a lot of users it may be useful to restrict the number of bookmarks per account." : "Asennuksissa, joissa on paljon käyttäjiä, voi olla mielekästä rajoittaa tilikohtaisten kirjanmerkkien enimmäismäärää.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Käyttäjätilikohtaisten kirjanmerkkien enimmäismäärä. (0 tarkoittaa ei rajoitusta; oletus on ei rajoitusta)",
     "Failed to load settings" : "Asetusten lataaminen epäonnistui",
     "Failed to save settings" : "Asetusten tallentaminen epäonnistui",
-    "Add a bookmark" : "Lisää kirjanmerkki",
     "This URL is already bookmarked! Overwrite?" : "Osoite on jo lisätty kirjanmerkkeihin. Korvataanko se?",
-    "Title" : "Otsikko",
-    "Link" : "Linkki",
+    "Enter bookmark title" : "Anna nimi kirjanmerkille",
     "Enter bookmark URL" : "Kirjoita kirjanmerkin osoite",
     "Folder" : "Kansio",
     "Root Folder" : "Juurikansio",
+    "Save" : "Tallenna",
+    "Failed to load bookmark" : "Kirjanmerkin lataaminen epäonnistui",
     "Failed to find existing bookmark" : "Olemassa olevaa kirjanmerkkiä ei löytynyt",
     "Failed to create bookmark" : "Kirjanmerkin luominen epäonnistui",
     "Failed to save bookmark" : "Kirjanmerkin tallentaminen epäonnistui",
@@ -105,8 +139,6 @@ OC.L10N.register(
     "Failed to load folders" : "Kansioiden lataaminen epäonnistui",
     "Failed to delete folder" : "Kansion poistaminen epäonnistui",
     "Failed to create folder" : "Kansion luominen epäonnistui",
-    "Failed to move parts of selection" : "Joidenkin valinnan osien siirtäminen epäonnistui",
-    "Failed to delete parts of selection" : "Joidenkin valinnan osien poistaminen epäonnistui",
     "Failed to fetch bookmarks." : "Kirjanmerkkien noutaminen epäonnistui.",
     "Failed to change setting" : "Asetuksen muuttaminen eppäonnistui",
     "Failed to load setting {key}" : "Asetuksen {key} lataaminen epäonnistui",
