@@ -11,11 +11,8 @@ OC.L10N.register(
     "Rename" : "שינוי שם",
     "Move" : "העברה",
     "Delete" : "מחיקה",
-    "Enter bookmark title" : "נא להקליד כותרת לסימנייה",
-    "Save" : "שמירה",
-    "No bookmarks here" : "אין כאן סימניות",
-    "Try changing your query or add some using the button on the left." : "כדאי לנסות לערוך את השאילתה או להוסיף שאילתה בעזרת הכםתור שמימין.",
     "Select one or more tags" : "יש לבחור תגית אחת או יותר",
+    "New" : "חדש",
     "New bookmark" : "סימנייה חדשה",
     "New folder" : "תיקייה חדשה",
     "Grid view" : "תצוגת טבלה",
@@ -23,28 +20,26 @@ OC.L10N.register(
     "Move selection" : "העברת בחירה",
     "Delete selection" : "מחיקת בחירה",
     "Open all selected" : "לפתוח את כל הנבחרים",
-    "Select all visible" : "בחירת כל הגלויות",
+    "Select all" : "בחר הכל",
     "Cancel selection" : "ביטול בחירה",
     "Selected {folders} folders and {bookmarks} bookmarks" : "נבחרו {folders} תיקיות ו־{bookmarks} סימניות",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["סימנייה אחת נבחרה","%n סימניות נבחרו","%n סימניות נבחרו","%n סימניות נבחרו"],
     "_Selected %n folder_::_Selected %n folders_" : ["נבחרה תיקייה %n","נבחרו %n תיקיות","נבחרו %n תיקיות","נבחרו %n תיקיות"],
     "Enter a link" : "נא למלא קישור",
-    "Create" : "יצירה",
-    "Cancel" : "ביטול",
-    "Enter folder title" : "נא למלא כותרת לתיקייה",
     "Select folder" : "בחירת תיקייה",
+    "Enter folder title" : "נא למלא כותרת לתיקייה",
     "Shared by {user}" : "שותפה על ידי {user}",
-    "Shared privately" : "שותפה בפרטיות",
-    "Public" : "ציבורי",
     "Root folder" : "תיקיית בסיס",
+    "Cancel" : "ביטול",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["תיקייה אחת ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות"],
     "_Moving %n folder_::_Moving %n folders_" : ["תיקייה אחת מועברת","%n תיקיות מועברות","%n תיקיות מועברות","%n תיקיות מועברות"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["סימנייה אחת מועברת","%n סימניות מועברות","%n סימניות מועברות","%n סימניות מועברות"],
-    "New Bookmark" : "סימנייה חדשה",
-    "All Bookmarks" : "כל הסימניות",
-    "Recent Bookmarks" : "סימניות אחרונות",
+    "All bookmarks" : "כל הסימניות",
+    "Recent" : "אחרונים",
     "Untagged" : "ללא תגית",
     "{used} bookmarks of {available} available" : "{used} סימניות מתוך {available} זמינות",
+    "No bookmarks here" : "אין כאן סימניות",
+    "Add a bookmark" : "הוספת סימנייה",
     "Import" : "ייבוא",
     "Export" : "ייצוא",
     "Sorting" : "מיון",
@@ -52,25 +47,23 @@ OC.L10N.register(
     "Alphabetically" : "בסדר האלף-בית",
     "Most visited" : "הכי הרבה ביקורים",
     "Last modified" : "מועד שינוי אחרון",
-    "RSS Feed" : "ערוץ RSS",
-    "This is an RSS feed of the current result set with access restricted to you." : "זו הזנת RSS של סדרת התוצאות הנוכחית כשהגישה מותרת לך בלבד.",
-    "Clear data" : "ניקוי מידע",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "הסרת כל הסימניות מהחשבון שלך לצמיתות. אי אפשר לחזור אחורה!",
-    "Delete all bookmarks" : "מחיקת כל הסימניות",
+    "Client apps" : "יישומוני לקוח",
+    "Also check out the collection of client apps that integrate with this app: " : "כדאי להציץ באוסף יישומוני הלקוח שמשתלבים עם היישומון הזה:",
     "Bookmarklet" : "יישומון סימנייה",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "יש לגרור זאת לדפדפן שלך וללחוץ על זה כדי להוסיף דף כלשהו כסימנייה",
     "Add to {instanceName}" : "הוספה אל {instanceName}",
-    "Also check out the collection of client apps that integrate with this app: " : "כדאי להציץ באוסף יישומוני הלקוח שמשתלבים עם היישומון הזה:",
-    "Client apps" : "יישומוני לקוח",
+    "Clear data" : "ניקוי מידע",
+    "Delete all bookmarks" : "מחיקת כל הסימניות",
     "Do you really want to delete all your bookmarks?" : "למחוק את כל הסימניות שלך?",
-    "URL" : "כתובת",
+    "Title" : "תפקיד",
+    "Link" : "קישור",
     "Creation date" : "מועד יצירה",
     "Tags" : "תגיות",
-    "Select tags are create new ones" : "נא לבחור תגיות או ליצור חדשות",
+    "Attachments" : "קבצים מצורפים",
     "Notes" : "הערות",
-    "Sharing" : "שיתוף",
     "{time} ago" : "לפני {time}",
     "Owner" : "בעלות",
+    "Sharing" : "שיתוף",
     "Select a user or group" : "נא לבחור משתמש או קבוצה",
     "Share link" : "קישור שיתוף",
     "Copy link" : "העתקת קישור",
@@ -82,7 +75,6 @@ OC.L10N.register(
     "Link copied" : "הקישור הועתק",
     "Select" : "בחירה",
     "Previews" : "תצוגות מקדימות",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "כדי להציג צילומי מסך אמתיים של האתרים שהוספת למועדפים, הסימניות יכולות להשתמש בשירות צד־שלישי כדי לייצר אותן.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "ניתן להירשם בחינם בכתובת screeenly.com או להקים שרת משלך.",
     "Screeenly API URL" : "כתובת ה־API של Screeenly",
@@ -91,16 +83,14 @@ OC.L10N.register(
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "תכנית הסימניות תנסה לגשת אל האתרים שהוספת כדי להוסיף עליהן מידע אוטומטית.",
     "Enable accessing and collecting information from the web pages you add" : "הפעלת גישה ואיסוף של מידע מהאתרים שהוספת.",
     "Performance" : "ביצועים",
-    "In an installation with  a lot of users it may be useful to restrict the number of bookmarks per account." : "בהתקנה עם הרבה משתמשים ייתכן שעדיף להגביל את כמות הסימניות לחשבון.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "כמות הסימניות המרבית לחשבון. (0 ללא הגבלה וזאת גם בררת המחדל)",
     "Failed to load settings" : "טעינת ההגדרות נכשלה",
     "Failed to save settings" : "שמירת ההגדרות נכשלה",
-    "Add a bookmark" : "הוספת סימנייה",
     "This URL is already bookmarked! Overwrite?" : "כתובת זו כבר נשמרה בסימניות! לשכתב?",
-    "Title" : "תפקיד",
-    "Link" : "קישור",
+    "Enter bookmark title" : "נא להקליד כותרת לסימנייה",
     "Enter bookmark URL" : "נא למלא כתובת סימנייה",
     "Folder" : "תיקייה",
+    "Save" : "שמירה",
     "Failed to find existing bookmark" : "איתור סימנייה קיימת נכשל",
     "Failed to create bookmark" : "יצירת סימנייה נכשלה",
     "Failed to save bookmark" : "שמירת סימנייה נכשלה",
@@ -110,8 +100,6 @@ OC.L10N.register(
     "Failed to load folders" : "טעינת התיקיות נכשלה",
     "Failed to delete folder" : "מחיקת התיקייה נכשלה",
     "Failed to create folder" : "יצירת התיקייה נכשלה",
-    "Failed to move parts of selection" : "העברת חלקים מהבחירה נכשלה",
-    "Failed to delete parts of selection" : "מחיקת חלקים מהבחירה נכשלה",
     "Failed to fetch bookmarks." : "קבלת הסימניות נכשלה.",
     "Failed to change setting" : "שינוי ההגדרות נכשל",
     "Failed to load setting {key}" : "טעינת ההגדרה {key} נכשלה",
