@@ -10,29 +10,27 @@ OC.L10N.register(
     "Rename" : "Átnevezés",
     "Move" : "Áthelyezés",
     "Delete" : "Törlés",
-    "Enter bookmark title" : "Adja meg a könyvjelző címét",
-    "Save" : "Mentés",
-    "No bookmarks here" : "Itt nincsenek könyvjelzők",
     "Select one or more tags" : "Válasszon egy vagy több címkét",
+    "New" : "Új",
     "New folder" : "Új mappa",
     "Grid view" : "Rács nézet",
     "List view" : "Lista nézet",
     "Move selection" : "Kiválasztás áthelyezése",
     "Delete selection" : "Kiválasztás törlése",
+    "Select all" : "Összes kijelölése",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n könyvjelző kiválasztva","%n könyvjelző kiválasztva"],
     "Enter a link" : "Adjon meg egy hivatkozást",
-    "Create" : "Létrehozás",
-    "Cancel" : "Mégse",
     "Enter folder title" : "Adja meg a mappa nevét",
-    "Public" : "Nyilvános",
     "Root folder" : "Gyökérmappa",
+    "Cancel" : "Mégse",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n mappa és néhány könyvjelző áthelyezése","%n mappa és néhány könyvjelző áthelyezése"],
     "_Moving %n folder_::_Moving %n folders_" : ["%n mappa áthelyezése","%n mappa áthelyezése"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n könyvjelző áthelyezése","%n könyvjelző áthelyezése"],
-    "New Bookmark" : "Új könyvjelző",
-    "All Bookmarks" : "Összes könyvjelző",
-    "Recent Bookmarks" : "Legújabb könyvjelzők",
+    "All bookmarks" : "Minden könyvjelző",
+    "Recent" : "Friss",
     "Untagged" : "Nem cimkézett",
+    "No bookmarks here" : "Itt nincsenek könyvjelzők",
+    "Add a bookmark" : "Könyvjelző hozzáadása",
     "Import" : "Import",
     "Export" : "Exportálás",
     "Sorting" : "Rendezés",
@@ -40,28 +38,27 @@ OC.L10N.register(
     "Alphabetically" : "Betűrendben",
     "Most visited" : "Legtöbbet látogatva",
     "Last modified" : "Utoljára módosítva",
-    "RSS Feed" : "RSS-csatorna",
-    "Clear data" : "Adatok törlése",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "Véglegesen törlöd az összes könyvjelzőt a fiókodból! Nincs visszaút!",
-    "Delete all bookmarks" : "Összes könyvjelzők törlése",
+    "Client apps" : "Kliensalkalmazások",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName}" : "Hozzáadás ehhez: {instanceName}",
-    "Client apps" : "Kliensalkalmazások",
+    "Clear data" : "Adatok törlése",
+    "Delete all bookmarks" : "Összes könyvjelzők törlése",
     "Do you really want to delete all your bookmarks?" : "Biztos, hogy törli az összes könyvjelzőt?",
-    "URL" : "URL",
+    "Title" : "Cím",
+    "Link" : "Hivatkozás",
     "Creation date" : "Létrehozás dátuma",
     "Tags" : "Cimkék",
-    "Select tags are create new ones" : "Válasszon címkéket, vagy hozzon létre újakat",
+    "Attachments" : "Mellékletek",
     "Notes" : "Jegyzetek",
-    "Sharing" : "Megosztás",
     "Owner" : "Tulajdonos",
+    "Sharing" : "Megosztás",
     "Share link" : "Hivatkozás megosztása",
     "Copy link" : "Hivatkozás másolása",
     "Allow editing" : "Szerkesztés engedélyezése",
+    "Remove share" : "Megosztás eltávolítása",
     "Link copied" : "Hivatkozás másolva",
     "Select" : "Kijelölés",
     "Previews" : "Előnézetek",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Ahhoz, hogy valódi képernyőképeket kapjon a könyvjelzőzött weboldalakról, a Könyvjelzőknek szüksége van egy harmadik fél által üzemeltetett szolgáltatásra, amely előállítja a képernyőképeket.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Ingyenesen regisztrálhat a screenly.com weboldalon, vagy beállíthatja a saját kiszolgálóját.",
     "Screeenly API URL" : "Screeenly API URL",
@@ -70,12 +67,11 @@ OC.L10N.register(
     "Performance" : "Teljesítmény",
     "Failed to load settings" : "A beállítások betöltése sikertelen",
     "Failed to save settings" : "A beállítások mentése sikertelen",
-    "Add a bookmark" : "Könyvjelző hozzáadása",
     "This URL is already bookmarked! Overwrite?" : "Ez a cím már jegyezve van. Felülírod?",
-    "Title" : "Cím",
-    "Link" : "Hivatkozás",
+    "Enter bookmark title" : "Adja meg a könyvjelző címét",
     "Enter bookmark URL" : "Adja meg a könyvjelző URL-ét",
     "Folder" : "Mappa",
+    "Save" : "Mentés",
     "Failed to find existing bookmark" : "A létező könyvjelző keresése sikertelen",
     "Failed to create bookmark" : "Könyvjelző létrehozása sikertelen",
     "Failed to save bookmark" : "Könyvjelző mentése sikertelen",
@@ -85,8 +81,6 @@ OC.L10N.register(
     "Failed to load folders" : "Mappák betöltése sikertelen",
     "Failed to delete folder" : "Mappa törlése sikertelen",
     "Failed to create folder" : "Mappa létrehozása sikertelen",
-    "Failed to move parts of selection" : "Kiválasztás részeinek áthelyezése sikertelen",
-    "Failed to delete parts of selection" : "Kiválasztás részeinek törlése sikertelen",
     "Failed to fetch bookmarks." : "Könyvjelzők lekérése sikertelen.",
     "Failed to change setting" : "Beállítások módosítása sikertelen",
     "Bookmarks feed" : "Könyvjelzők folyam"
