@@ -11,10 +11,8 @@ OC.L10N.register(
     "Rename" : "Ubah nama",
     "Move" : "Pindah",
     "Delete" : "Hapus",
-    "Enter bookmark title" : "Tulis judul markah",
-    "Save" : "Simpan",
-    "No bookmarks here" : "Tidak ada markah disini",
     "Select one or more tags" : "Pilih satu atau lebih tag",
+    "New" : "Baru",
     "New bookmark" : "Markah baru",
     "New folder" : "Folder baru",
     "Grid view" : "Tampilan kotak",
@@ -22,39 +20,37 @@ OC.L10N.register(
     "Move selection" : "Pindah pilihan",
     "Delete selection" : "Hapus pilihan",
     "Open all selected" : "Buka semua pilihan",
-    "Select all visible" : "Pilih semua yang tampil",
+    "Select all" : "Pilih semua",
     "Cancel selection" : "Batalkan pilihan",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Memilih %n markah"],
     "_Selected %n folder_::_Selected %n folders_" : ["Memilih %n folder"],
-    "Create" : "Buat",
-    "Cancel" : "Membatalkan",
     "Select folder" : "Pilih folder",
     "Shared by {user}" : "Dibagikan oleh {user}",
-    "Shared privately" : "Dibagikan secara privat",
-    "Public" : "Publik",
     "Root folder" : "Folder akar",
+    "Cancel" : "Membatalkan",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Memindahkan %n folder dan beberapa markah"],
     "_Moving %n folder_::_Moving %n folders_" : ["Memindahkan %n folder"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Memindahkan %n markah"],
-    "New Bookmark" : "Markah baru",
-    "All Bookmarks" : "Semua markah",
-    "Recent Bookmarks" : "Markah terbaru",
+    "Recent" : "Terbaru",
     "Untagged" : "Belum ada tag",
+    "No bookmarks here" : "Tidak ada markah disini",
+    "Add a bookmark" : "Tambahkan markah",
     "Import" : "Impor",
     "Export" : "Ekspor",
     "Recently added" : "Baru ditambah",
     "Most visited" : "Sering dikunjungi",
     "Last modified" : "Terakhir diubah",
-    "RSS Feed" : "Umpan RSS",
+    "Client apps" : "Aplikasi klien",
     "Clear data" : "Bersihkan data",
     "Delete all bookmarks" : "Hapus semua markah",
-    "Client apps" : "Aplikasi klien",
-    "URL" : "URL",
+    "Title" : "Judul",
+    "Link" : "Tautan",
     "Creation date" : "Tanggal pembuatan",
     "Tags" : "Tag",
+    "Attachments" : "Lampiran",
     "Notes" : "Catatan",
-    "Sharing" : "Berbagi",
     "Owner" : "Owner",
+    "Sharing" : "Berbagi",
     "Select a user or group" : "Pilih pengguna atau grup",
     "Share link" : "Bagikan tautan",
     "Copy link" : "Salin tautan",
@@ -70,12 +66,11 @@ OC.L10N.register(
     "Privacy" : "Privasi",
     "Performance" : "Performa",
     "Failed to save settings" : "Gagal simpan setelan",
-    "Add a bookmark" : "Tambahkan markah",
-    "Title" : "Judul",
-    "Link" : "Tautan",
+    "Enter bookmark title" : "Tulis judul markah",
     "Enter bookmark URL" : "Tulis URL markah",
     "Folder" : "Folder",
     "Root Folder" : "Folder Akar",
+    "Save" : "Simpan",
     "Failed to find existing bookmark" : "Gagal mencari markah eksis",
     "Failed to create bookmark" : "Gagal membuat markah",
     "Failed to save bookmark" : "Gagal menyimpan markah",
@@ -85,8 +80,6 @@ OC.L10N.register(
     "Failed to load folders" : "Gagal memuat folder",
     "Failed to delete folder" : "Gagal menghapus folder",
     "Failed to create folder" : "Gagal membuat folder",
-    "Failed to move parts of selection" : "Gagal memindahkan sebagai pilihan",
-    "Failed to delete parts of selection" : "Gagal menghapus sebagian pilihan",
     "Failed to fetch bookmarks." : "Gagal menampilkan markah",
     "Failed to change setting" : "Gagal mengubah setelan",
     "Failed to load setting {key}" : "Gagal memuat setelan {key}",
