@@ -2,6 +2,18 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "Adresynas",
+    "You deleted \"%s\"" : "Jūs ištrynėte \"%s\"",
+    "%1$s deleted \"%2$s\"" : "%1$s ištrynė \"%2$s\"",
+    "Someone deleted \"%s\"" : "Kažkas ištrynė \"%s\"",
+    "You created folder \"%s\"" : "Jūs sukūrėte aplanką \"%s\"",
+    "%1$s created folder \"%2$s\"" : "%1$s sukūrė aplanką \"%2$s\"",
+    "Someone created folder \"%s\"" : "Kažkas sukūrė aplanką \"%s\"",
+    "You moved folder \"%s\"" : "Jūs perkėlėte aplanką \"%s\"",
+    "%1$s moved folder \"%2$s\"" : "%1$s perkėlė aplanką \"%2$s\"",
+    "Someone moved folder \"%s\"" : "Kažkas perkėlė aplanką \"%s\"",
+    "You deleted folder \"%s\"" : "Jūs ištrynėte aplanką \"%s\"",
+    "%1$s deleted folder \"%2$s\"" : "%1$s ištrynė aplanką \"%2$s\"",
+    "Someone deleted folder \"%s\"" : "Kažkas ištrynė aplanką \"%s\"",
     "No file provided for import" : "Importavimui nepateiktas joks failas",
     "Unsupported file type for import" : "Importavimui pateiktas nepalaikomas failo tipas",
     "A Bookmark manager for Nextcloud" : "Adresyno tvarkytuvė, skirta Nextcloud",
@@ -10,30 +22,26 @@ OC.L10N.register(
     "Rename" : "Pervadinti",
     "Move" : "Perkelti",
     "Delete" : "Ištrinti",
-    "Enter bookmark title" : "Įveskite adresyno įrašo pavadinimą",
-    "Save" : "Įrašyti",
-    "No bookmarks here" : "Čia adresyno įrašų nėra",
-    "Try changing your query or add some using the button on the left." : "Pabandykite pakeisti savo užklausą arba pridėkite adresyno įrašą naudodami kairėje esantį mygtuką.",
     "Select one or more tags" : "Pasirinkite vieną ar daugiau žymių",
+    "New" : "Nauja",
     "New folder" : "Naujas aplankas",
     "Grid view" : "Tinklelio rodinys",
     "List view" : "Sąrašo rodinys",
     "Move selection" : "Perkelti žymėjimą",
     "Delete selection" : "Ištrinti žymėjimą",
+    "Select all" : "Pažymėti viską",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Pažymėtas %n adresyno įrašas","Pažymėti %n adresyno įrašai","Pažymėta %n adresyno įrašų","Pažymėtas %n adresyno įrašas"],
     "Enter a link" : "Įveskite nuorodą",
-    "Create" : "Sukurti",
-    "Cancel" : "Atsisakyti",
     "Enter folder title" : "Įveskite aplanko pavadinimą",
-    "Public" : "Vieša",
     "Root folder" : "Šakninis aplankas",
+    "Cancel" : "Atsisakyti",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Perkeliamas %n aplankas ir keli adresyno įrašai","Perkeliami %n aplankai ir keli adresyno įrašai","Perkeliama %n aplankų ir keli adresyno įrašai","Perkeliamas %n aplankas ir keli adresyno įrašai"],
     "_Moving %n folder_::_Moving %n folders_" : ["Perkeliamas %n aplankas","Perkeliami %n aplankai","Perkeliama %n aplankų","Perkeliamas %n aplankas"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Perkeliamas %n adresyno įrašas","Perkeliami %n adresyno įrašai","Perkeliama %n adresyno įrašų","Perkeliamas %n adresyno įrašas"],
-    "New Bookmark" : "Naujas adresyno įrašas",
-    "All Bookmarks" : "Visi adresyno įrašai",
-    "Recent Bookmarks" : "Paskiausi adresyno įrašai",
+    "Recent" : "Paskiausi",
     "Untagged" : "Be žymių",
+    "No bookmarks here" : "Čia adresyno įrašų nėra",
+    "Add a bookmark" : "Pridėti adresyno įrašą",
     "Import" : "Importuoti",
     "Export" : "Eksportuoti",
     "Sorting" : "Rikiavimas",
@@ -41,29 +49,30 @@ OC.L10N.register(
     "Alphabetically" : "Pagal abėcėlę",
     "Most visited" : "Daugiausiai lankyti",
     "Last modified" : "Paskutinis modifikavimas",
-    "RSS Feed" : "RSS kanalas",
-    "Clear data" : "Išvalyti duomenis",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "Visiems laikams pašalinti visus adresyno įrašus iš jūsų paskyros. Nebus jokio kelio atgal!",
-    "Delete all bookmarks" : "Ištrinti visą adresyną",
-    "Add to {instanceName}" : "Pridėti į {instanceName}",
     "Client apps" : "Kliento programėlės",
+    "Add to {instanceName}" : "Pridėti į {instanceName}",
+    "Clear data" : "Išvalyti duomenis",
+    "Delete all bookmarks" : "Ištrinti visą adresyną",
     "Do you really want to delete all your bookmarks?" : "Ar tikrai norite ištrinti visus savo adresyno įrašus?",
-    "URL" : "URL",
+    "Title" : "Pareigos",
+    "Link" : "Nuoroda",
     "Creation date" : "Sukūrimo data",
     "Tags" : "Žymės",
-    "Select tags are create new ones" : "Pasirinkite žymes arba sukurkite naujas",
+    "Attachments" : "Priedai",
     "Notes" : "Pastabos",
-    "Sharing" : "Bendrinimas",
     "{time} ago" : "Prieš {time}",
     "Owner" : "Savininkas",
+    "Sharing" : "Bendrinimas",
     "Select a user or group" : "Pasirinkti naudotoją ar grupę",
     "Share link" : "Bendrinimo nuoroda",
     "Copy link" : "Kopijuoti nuorodą",
+    "Copy RSS feed" : "Kopijuoti RSS kanalą",
     "Delete link" : "Ištrinti nuorodą",
     "Create public link" : "Sukurti viešąją nuorodą",
     "Allow editing" : "Leisti redaguoti",
     "Remove share" : "Šalinti viešinį",
     "Link copied" : "Nuoroda nukopijuota",
+    "RSS feed copied" : "RSS kanalas nukopijuotas",
     "Select" : "Pasirinkti",
     "Previews" : "Peržiūros",
     "Screeenly" : "Screeenly",
@@ -74,27 +83,24 @@ OC.L10N.register(
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Adresynas bandys apsilankyti jūsų pridedamose internetinėse svetainėse, kad automatiškai pridėtų informaciją apie jas.",
     "Enable accessing and collecting information from the web pages you add" : "Leisti apsilankyti ir rinkti iš saityno informaciją apie jūsų pridedamus internetinius puslapius",
     "Performance" : "Našumas",
-    "In an installation with  a lot of users it may be useful to restrict the number of bookmarks per account." : "Diegime su daugybe naudotojų gali būti naudinga apriboti kiekvienai paskyrai tenkantį adresyno įrašų skaičių.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Didžiausias, vienai paskyrai leidžiamas, adresyno įrašų skaičius. (0, kad būtų neribojama; pagal numatymą yra neribojama)",
     "Failed to load settings" : "Nepavyko įkelti nustatymų",
     "Failed to save settings" : "Nepavyko įrašyti nustatymų",
-    "Add a bookmark" : "Pridėti adresyno įrašą",
     "This URL is already bookmarked! Overwrite?" : "Šis URL jau įtrauktas į adresyną! Perrašyti?",
-    "Title" : "Pareigos",
-    "Link" : "Nuoroda",
+    "Enter bookmark title" : "Įveskite adresyno įrašo pavadinimą",
     "Enter bookmark URL" : "Įveskite adresyno įrašo URL",
     "Folder" : "Aplankas",
+    "Save" : "Įrašyti",
     "Failed to find existing bookmark" : "Nepavyko rasti esamo adresyno įrašo",
     "Failed to create bookmark" : "Nepavyko sukurti adresyno įrašo",
     "Failed to save bookmark" : "Nepavyko įrašyti adresyno įrašo",
     "Failed to move bookmark" : "Nepavyko perkelti adresyno įrašo",
     "Failed to delete bookmark" : "Nepavyko ištrinti adresyno įrašo",
+    "Failed to rename tag" : "Nepavyko pervadinti žymės",
     "Failed to load tags" : "Nepavyko įkelti žymių",
     "Failed to load folders" : "Nepavyko įkelti aplankų",
     "Failed to delete folder" : "Nepavyko ištrinti aplanko",
     "Failed to create folder" : "Nepavyko sukurti aplanko",
-    "Failed to move parts of selection" : "Nepavyko perkelti tam tikros žymėjimo dalies",
-    "Failed to delete parts of selection" : "Nepavyko ištrinti tam tikros žymėjimo dalies",
     "Failed to fetch bookmarks." : "Nepavyko gauti adresyno įrašų.",
     "Failed to change setting" : "Nepavyko pakeisti nustatymo",
     "Failed to load setting {key}" : "Nepavyko įkelti nustatymo {key}",
