@@ -5,22 +5,22 @@ OC.L10N.register(
     "Rename" : "Renomenar",
     "Move" : "Move",
     "Delete" : "Suprimir",
-    "Save" : "Salvar",
+    "New" : "Novèl",
     "New folder" : "Novèl dorsièr",
-    "Create" : "Crear",
     "Cancel" : "Anullar",
+    "Recent" : "Recents",
     "Import" : "Importar",
     "Export" : "Exportar",
-    "URL" : "URL",
+    "Title" : "Títol",
+    "Link" : "Ligam",
     "Notes" : "Nòtas",
-    "Sharing" : "Partiment",
     "Owner" : "Owner",
+    "Sharing" : "Partiment",
     "Share link" : "Partejar lo ligam",
     "Copy link" : "Copiar lo ligam",
     "Allow editing" : "Permetre la modificacion",
     "Select" : "Select",
-    "Title" : "Títol",
-    "Link" : "Ligam",
-    "Folder" : "Dorsièr"
+    "Folder" : "Dorsièr",
+    "Save" : "Salvar"
 },
 "nplurals=2; plural=(n > 1);");
