@@ -5,30 +5,30 @@ OC.L10N.register(
     "Rename" : "Redenumire",
     "Move" : "Mută",
     "Delete" : "Șterge",
-    "Save" : "Salvează",
+    "New" : "Nou",
     "New folder" : "Director nou",
     "Grid view" : "Afișare în grilă",
     "List view" : "Afișare în listă",
-    "Create" : "Creează",
+    "Select all" : "Selectează tot",
     "Cancel" : "Anulează",
-    "Public" : "Public",
+    "Recent" : "Recente",
     "Import" : "Importă",
     "Export" : "Exportă",
     "Recently added" : "Adăugate recent",
     "Clear data" : "Elimină datele",
-    "URL" : "URL",
+    "Title" : "Titlu",
+    "Link" : "Legătură",
     "Tags" : "Etichete",
     "Notes" : "Notițe",
-    "Sharing" : "Partajare",
     "Owner" : "Proprietar",
+    "Sharing" : "Partajare",
     "Share link" : "Partajează link-ul",
     "Copy link" : "Copiză link",
     "Allow editing" : "Permite editarea",
     "Link copied" : "Link copiat",
     "Select" : "Select",
     "Privacy" : "Confindențialitate",
-    "Title" : "Titlu",
-    "Link" : "Legătură",
-    "Folder" : "Director"
+    "Folder" : "Director",
+    "Save" : "Salvează"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
