@@ -5,13 +5,13 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Move" : "Zhvendos",
     "Delete" : "Fshij",
-    "Save" : "Ruaj",
+    "New" : "I ri",
     "New folder" : "Dosje e re",
     "Grid view" : "Pamje galeri",
     "List view" : "Pamje listë",
-    "Create" : "Krijo",
+    "Select all" : "Zgjidhi të gjitha",
     "Cancel" : "Anullo",
-    "Public" : "Publik",
+    "Recent" : "Së fundmi",
     "Untagged" : "E paetiketuar",
     "Import" : "Import",
     "Export" : "Eksport",
@@ -19,13 +19,15 @@ OC.L10N.register(
     "Alphabetically" : "Alfabetikisht",
     "Most visited" : "Vizituar më shpesh",
     "Last modified" : "Ndryshuar së fundmi",
-    "Clear data" : "Pastroji të dhënat",
     "Bookmarklet" : "Libër Shënues",
-    "URL" : "Url",
+    "Clear data" : "Pastroji të dhënat",
+    "Title" : "Titulli",
+    "Link" : "Lidhje",
     "Tags" : "Etiketat",
+    "Attachments" : "Bashkangjitjet",
     "Notes" : "Shënime",
-    "Sharing" : "Ndarje",
     "Owner" : "Zotëruesi",
+    "Sharing" : "Ndarje",
     "Share link" : "Share link",
     "Copy link" : "Kopjo linkun",
     "Allow editing" : "Lejo redaktimin",
@@ -33,8 +35,7 @@ OC.L10N.register(
     "Select" : "Përzgjidh",
     "Previews" : "Parapamjet",
     "Privacy" : "Privatësia",
-    "Title" : "Titulli",
-    "Link" : "Lidhje",
-    "Folder" : "Skedari"
+    "Folder" : "Skedari",
+    "Save" : "Ruaj"
 },
 "nplurals=2; plural=(n != 1);");
