@@ -4,21 +4,20 @@ OC.L10N.register(
     "Rename" : "ئات ئۆزگەرت",
     "Move" : "Move",
     "Delete" : "ئۆچۈر",
-    "Save" : "ساقلا",
+    "New" : "يېڭى",
     "New folder" : "يېڭى قىسقۇچ",
-    "Create" : "قۇر",
     "Cancel" : "ۋاز كەچ",
     "Import" : "ئەكىر",
     "Export" : "چىقار",
-    "URL" : "URL",
-    "Tags" : "بەلگەلەر",
-    "Notes" : "ئىزاھاتلار",
-    "Sharing" : "ھەمبەھىر",
-    "Owner" : "Owner",
-    "Share link" : "Share link",
-    "Select" : "Select",
     "Title" : "ماۋزۇ",
     "Link" : "Link",
-    "Folder" : "قىسقۇچ"
+    "Tags" : "بەلگەلەر",
+    "Notes" : "ئىزاھاتلار",
+    "Owner" : "Owner",
+    "Sharing" : "ھەمبەھىر",
+    "Share link" : "Share link",
+    "Select" : "Select",
+    "Folder" : "قىسقۇچ",
+    "Save" : "ساقلا"
 },
 "nplurals=2; plural=(n != 1);");
