@@ -8,24 +8,27 @@ OC.L10N.register(
     "Rename" : "Перейменувати",
     "Move" : "Перемістити",
     "Delete" : "Вилучити",
-    "Save" : "Зберегти",
+    "New" : "Створити",
     "New folder" : "Нова тека",
     "Grid view" : "Упорядкування у формі сітки",
     "List view" : "Упорядкування у формі списку",
-    "Create" : "Створити",
+    "Select all" : "Вибрати все",
     "Cancel" : "Скасувати",
-    "Public" : "Публічне",
+    "Recent" : "Нещодавні",
+    "Add a bookmark" : "Додати закладку",
     "Import" : "Імпорт",
     "Export" : "Експорт",
     "Recently added" : "Нещодавно додані",
     "Alphabetically" : "За алфавітом",
     "Last modified" : "Останні зміни",
     "Clear data" : "Очистити дані",
-    "URL" : "URL-адреса",
+    "Title" : "Назва",
+    "Link" : "Посилання",
     "Tags" : "Позначки",
+    "Attachments" : "Вкладення",
     "Notes" : "Нотатки",
-    "Sharing" : "Поділитись",
     "Owner" : "Власник",
+    "Sharing" : "Поділитись",
     "Select a user or group" : "Виберіть користувача або групу",
     "Share link" : "Поширити посилання",
     "Copy link" : "Скопіювати посилання",
@@ -34,10 +37,8 @@ OC.L10N.register(
     "Select" : "Вибрати",
     "Privacy" : "Конфіденційність",
     "Failed to save settings" : "Неможливо зберегти налаштування",
-    "Add a bookmark" : "Додати закладку",
     "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
-    "Title" : "Назва",
-    "Link" : "Посилання",
-    "Folder" : "Папка"
+    "Folder" : "Папка",
+    "Save" : "Зберегти"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
