@@ -6,26 +6,28 @@ OC.L10N.register(
     "Rename" : "Đổi tên",
     "Move" : "Dịch chuyển",
     "Delete" : "Xóa",
-    "Enter bookmark title" : "Nhập tiêu đề bookmark",
-    "Save" : "Lưu",
     "Select one or more tags" : "Chọn một hoặc nhiều thẻ",
+    "New" : "Tạo mới",
     "New folder" : "Tạo thư mục",
     "Grid view" : "Xem dạng Lưới",
     "List view" : "Xem dạng Danh sách",
-    "Create" : "Tạo mới",
-    "Cancel" : "Hủy bỏ",
+    "Select all" : "Chọn tất cả",
     "Enter folder title" : "Nhập tiêu đề thư mục",
-    "Public" : "Công khai",
+    "Cancel" : "Hủy bỏ",
+    "Recent" : "Gần đây",
+    "Add a bookmark" : "Thêm một bookmark",
     "Import" : "Nhập vào",
     "Export" : "Xuất ra",
     "Recently added" : "Mới thêm",
     "Last modified" : "Lần cuối chỉnh sửa",
     "Clear data" : "Xóa dữ liệu",
-    "URL" : "URL",
+    "Title" : "Tên",
+    "Link" : "Liên kết",
     "Tags" : "Thẻ",
+    "Attachments" : "Đính kèm",
     "Notes" : "Ghi chép",
-    "Sharing" : "Đang chia sẽ",
     "Owner" : "Chủ",
+    "Sharing" : "Đang chia sẽ",
     "Share link" : "Chia sẽ liên kết",
     "Copy link" : "Sao chép liên kết",
     "Allow editing" : "Cho phép chỉnh sửa",
@@ -33,10 +35,9 @@ OC.L10N.register(
     "Privacy" : "Riêng tư",
     "Failed to load settings" : "Tải cấu hình thất bại",
     "Failed to save settings" : "Lưu cấu hình thất bại",
-    "Add a bookmark" : "Thêm một bookmark",
-    "Title" : "Tên",
-    "Link" : "Liên kết",
+    "Enter bookmark title" : "Nhập tiêu đề bookmark",
     "Folder" : "Thư mục",
-    "Root Folder" : "Thư mục gốc"
+    "Root Folder" : "Thư mục gốc",
+    "Save" : "Lưu"
 },
 "nplurals=1; plural=0;");
