@@ -10,29 +10,26 @@ OC.L10N.register(
     "Rename" : "重新命名",
     "Move" : "移動",
     "Delete" : "刪除",
-    "Enter bookmark title" : "輸入書籤標題",
-    "Save" : "儲存",
-    "No bookmarks here" : "無書籤",
     "Select one or more tags" : "選擇一個或是多個標記",
+    "New" : "新增",
     "New folder" : "新增資料夾",
     "Grid view" : "網格檢視",
     "List view" : "清單檢視",
     "Move selection" : "移動選擇",
     "Delete selection" : "刪除選擇",
+    "Select all" : "全選",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["選擇 %n 書籤"],
     "Enter a link" : "輸入一個連結",
-    "Create" : "建立",
-    "Cancel" : "取消",
     "Enter folder title" : "輸入資料夾標題",
-    "Public" : "公開",
     "Root folder" : "根目錄",
+    "Cancel" : "取消",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移動%n資料夾和一些書籤"],
     "_Moving %n folder_::_Moving %n folders_" : ["移動%n個資料夾"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移動%n個書籤"],
-    "New Bookmark" : "新書籤",
-    "All Bookmarks" : "所有書籤",
-    "Recent Bookmarks" : "最近的書籤",
+    "Recent" : "近期",
     "Untagged" : "未標記",
+    "No bookmarks here" : "無書籤",
+    "Add a bookmark" : "新增書籤",
     "Import" : "匯入",
     "Export" : "輸出",
     "Sorting" : "排序",
@@ -40,29 +37,28 @@ OC.L10N.register(
     "Alphabetically" : "字母",
     "Most visited" : "最常存取",
     "Last modified" : "上一次修改",
-    "RSS Feed" : "RSS Feed",
-    "Clear data" : "清除資料",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "從您的帳戶中永久移除所有的書籤，此操作無法復原",
-    "Delete all bookmarks" : "刪除所有書籤",
+    "Client apps" : "客戶端 apps",
     "Bookmarklet" : "書籤",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "拖拉這到您瀏覽器的書籤且點擊他以快速的對網頁作書籤",
     "Add to {instanceName}" : "加到 {instanceName}",
-    "Client apps" : "客戶端 apps",
+    "Clear data" : "清除資料",
+    "Delete all bookmarks" : "刪除所有書籤",
     "Do you really want to delete all your bookmarks?" : "您確定要刪除所有的書籤嗎？",
-    "URL" : "網址",
+    "Title" : "標題",
+    "Link" : "連結",
     "Creation date" : "建立時間",
     "Tags" : "標籤",
+    "Attachments" : "附件",
     "Notes" : "筆記",
-    "Sharing" : "分享",
     "{time} ago" : "{time}以前",
     "Owner" : "擁有者",
+    "Sharing" : "分享",
     "Share link" : "分享連結",
     "Copy link" : "複製連結",
     "Allow editing" : "允許編輯",
     "Link copied" : "連結已複製",
     "Select" : "選擇",
     "Previews" : "預覽",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "為了顯示您書籤的及時畫面，Bookmarks程式會使用第三方服務來產生螢幕截圖",
     "You can either sign up for free at screeenly.com or setup your own server." : "您可以免費在 screeenly.com 註冊或是設定您自己的伺服器。",
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Screeenly API key",
@@ -72,12 +68,11 @@ OC.L10N.register(
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每個帳號可以允許的書籤最大數量。(0是無限制; 預設是無限制)",
     "Failed to load settings" : "載入設定失敗",
     "Failed to save settings" : "設定儲存失敗",
-    "Add a bookmark" : "新增書籤",
     "This URL is already bookmarked! Overwrite?" : "此連結已存在，是否複寫？",
-    "Title" : "標題",
-    "Link" : "連結",
+    "Enter bookmark title" : "輸入書籤標題",
     "Enter bookmark URL" : "輸入書籤URL",
     "Folder" : "資料夾",
+    "Save" : "儲存",
     "Failed to find existing bookmark" : "尋找現存的書籤失敗",
     "Failed to create bookmark" : "建立書籤失敗",
     "Failed to save bookmark" : "儲存書籤失敗",
@@ -87,8 +82,6 @@ OC.L10N.register(
     "Failed to load folders" : "載入資料夾失敗",
     "Failed to delete folder" : "刪除資料夾失敗",
     "Failed to create folder" : "建立資料夾失敗",
-    "Failed to move parts of selection" : "移動部分選擇失敗",
-    "Failed to delete parts of selection" : "刪除部分選擇失敗",
     "Failed to fetch bookmarks." : "擷取書籤失敗",
     "Failed to change setting" : "變更設定失敗",
     "Bookmarks feed" : "Bookmarks feed"
