@@ -22,6 +22,10 @@ use OCP\AppFramework\Db\Entity;
  * @method setClickcount(int $count)
  * @method getLastPreview
  * @method setLastPreview(int $lastpreview)
+ * @method getAvailable
+ * @method setAvailable(boolean $available)
+ * @method getArchivedFile
+ * @method setArchivedFile(int $fileId)
  * @method getUserId
  * @method setUserId(string $userId)
  */
@@ -35,9 +39,11 @@ class Bookmark extends Entity {
 	protected $lastmodified;
 	protected $clickcount;
 	protected $lastPreview;
+	protected $available;
+	protected $archivedFile;
 
-	public static $columns = ['id', 'url', 'title', 'description', 'lastmodified', 'added', 'clickcount', 'last_preview', 'user_id'];
-	public static $fields = ['id', 'url', 'title', 'description', 'lastmodified', 'added', 'clickcount', 'lastPreview', 'userId'];
+	public static $columns = ['id', 'url', 'title', 'description', 'lastmodified', 'added', 'clickcount', 'last_preview', 'available', 'archived_file', 'user_id'];
+	public static $fields = ['id', 'url', 'title', 'description', 'lastmodified', 'added', 'clickcount', 'lastPreview', 'available', 'archivedFile', 'userId'];
 
 	public static function fromArray($props) {
 		$bookmark = new Bookmark();
@@ -58,6 +64,8 @@ class Bookmark extends Entity {
 		$this->addType('lastmodified', 'integer');
 		$this->addType('clickcount', 'integer');
 		$this->addType('lastPreview', 'integer');
+		$this->addType('available', 'boolean');
+		$this->addType('archivedFile', 'integer');
 	}
 
 	public function toArray(): array {
