@@ -47,6 +47,10 @@ class BookmarkMapper extends QBMapper {
 	 * @var TagMapper
 	 */
 	private $tagMapper;
+	/**
+	 * @var IQueryBuilder
+	 */
+	private $deleteTagsQuery;
 
 	/**
 	 * BookmarkMapper constructor.
@@ -66,6 +70,33 @@ class BookmarkMapper extends QBMapper {
 		$this->limit = (int)$config->getAppValue('bookmarks', 'performance.maxBookmarksperAccount', 0);
 		$this->publicMapper = $publicMapper;
 		$this->tagMapper = $tagMapper;
+
+		$this->deleteTagsQuery = $this->getDeleteTagsQuery();
+	}
+
+	protected function getDeleteTagsQuery() {
+		$qb = $this->db->getQueryBuilder();
+		$qb
+			->delete('bookmarks_tags')
+			->where($qb->expr()->eq('bookmark_id', $qb->createParameter('id')));
+		return $qb;
+	}
+
+	/**
+	 * @param string $userId
+	 * @throws DoesNotExistException
+	 * @throws MultipleObjectsReturnedException
+	 */
+	public function deleteAll(string $userId): void {
+		$qb = $this->db->getQueryBuilder();
+		$qb->select('b.id')
+			->from('bookmarks', 'b')
+			->where($qb->expr()->eq('b.user_id', $qb->createPositionalParameter($userId)));
+		$orphanedBookmarks = $qb->execute();
+		while ($bookmark = $orphanedBookmarks->fetchColumn()) {
+			$bm = $this->find($bookmark);
+			$this->delete($bm);
+		}
 	}
 
 	/**
@@ -74,9 +105,13 @@ class BookmarkMapper extends QBMapper {
 	 * @return Entity
 	 */
 	protected function mapRowToEntity(array $row): Entity {
-		$hasTags = array_first(array_keys($row), static function ($field) {
-			return preg_match('#.*tag|folder.*#i', $field, $matches) === 1; // 1 means it matches, 0 means it doesn't.
-		}, false);
+		$hasTags = false;
+		foreach (array_keys($row) as $field) {
+			if (preg_match('#.*tag|folder.*#i', $field, $matches) === 1) { // 1 means it matches, 0 means it doesn't.
+				$hasTags = true;
+				break;
+			}
+		}
 		if ($hasTags !== false) {
 			return BookmarkWithTagsAndParent::fromRow($row);
 		}
@@ -425,10 +460,8 @@ class BookmarkMapper extends QBMapper {
 
 		$id = $entity->getId();
 
-		$qb = $this->db->getQueryBuilder();
-		$qb
-			->delete('bookmarks_tags')
-			->where($qb->expr()->eq('bookmark_id', $qb->createPositionalParameter($id)));
+		$qb = $this->deleteTagsQuery;
+		$qb->setParameter('id', $id);
 		$qb->execute();
 
 		return $returnedEntity;
