@@ -15,6 +15,8 @@ export const privateRoutes = {
 	BOOKMARK: 'bookmark',
 	TAGS: 'tags',
 	UNTAGGED: 'untagged',
+	UNAVAILABLE: 'UNAVAILABLE',
+	ARCHIVED: 'ARCHIVED',
 	BOOKMARKLET: 'bookmarklet',
 }
 
@@ -59,7 +61,7 @@ export default new Router({
 			component: ViewPrivate,
 		},
 		{
-			path: '/tags/:tags',
+			path: '/tags/:tags?',
 			name: privateRoutes.TAGS,
 			component: ViewPrivate,
 		},
@@ -68,6 +70,16 @@ export default new Router({
 			name: privateRoutes.UNTAGGED,
 			component: ViewPrivate,
 		},
+		{
+			path: '/unavailable',
+			name: privateRoutes.UNAVAILABLE,
+			component: ViewPrivate,
+		},
+		{
+			path: '/archived',
+			name: privateRoutes.ARCHIVED,
+			component: ViewPrivate,
+		},
 		{
 			path: '/bookmarklet',
 			name: privateRoutes.BOOKMARKLET,
