@@ -2,26 +2,50 @@
 
 namespace OCA\Bookmarks\Tests;
 
-use OCA\Bookmarks\BackgroundJobs\PreviewsJob;
+use OCA\Bookmarks\BackgroundJobs\CrawlJob;
 use OC\BackgroundJob\JobList;
 use OCA\Bookmarks\Db\Bookmark;
 use OCA\Bookmarks\Db\BookmarkMapper;
-use OCA\Bookmarks\Service\Authorizer;
+use OCP\IConfig;
 use PHPUnit\Framework\TestCase;
 
 /**
  * Class Test_BackgroundJob
  */
 class BackgroundJobTest extends TestCase {
+	/**
+	 * @var mixed|\stdClass
+	 */
+	private $bookmarkMapper;
+	/**
+	 * @var mixed|\stdClass
+	 */
+	private $previewsJob;
+	/**
+	 * @var mixed|\stdClass
+	 */
+	private $jobList;
+	/**
+	 * @var mixed|\stdClass
+	 */
+	private $settings;
+	/**
+	 * @var string
+	 */
+	private $userId;
+
 	protected function setUp() :void {
 		parent::setUp();
 
 		$this->bookmarkMapper = \OC::$server->query(BookmarkMapper::class);
-		$this->previewsJob = \OC::$server->query(PreviewsJob::class);
+		$this->previewsJob = \OC::$server->query(CrawlJob::class);
 		$this->jobList = \OC::$server->query(JobList::class);
+		$this->settings = \OC::$server->query(IConfig::class);
 		$this->userId = 'test';
 
-		array_map(function($bm) {
+		$this->settings->setAppValue('bookmarks', 'privacy.enableScraping', 'true');
+
+		array_map(function ($bm) {
 			$this->bookmarkMapper->insert($bm);
 		}, $this->singleBookmarksProvider());
 	}
@@ -37,13 +61,14 @@ class BackgroundJobTest extends TestCase {
 	 * @return array
 	 */
 	public function singleBookmarksProvider() {
-		return array_map(function($props) {
+		return array_map(function ($props) {
 			return Bookmark::fromArray($props);
 		}, [
 			'Simple URL with title and description' => ['url' => 'https://google.com/', 'title' => 'Google', 'description' => 'Search engine'],
 			'Simple URL with title' => ['url' => 'https://nextcloud.com/', 'title' => 'Nextcloud'],
 			'Simple URL' => ['url' => 'https://php.net/'],
 			'URL with unicode' => ['url' => 'https://de.wikipedia.org/wiki/%C3%9C'],
+			'Non-existent URL' => ['url' => 'https://http://www.bllaala.com/'],
 		]);
 	}
 }
